package com.emitrom.pilot.maps.client.libraries.geometry;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.emitrom.pilot.core.shared.client.core.JsoHelper;
import com.emitrom.pilot.maps.client.base.LatLng;
import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.core.client.JsArray;

/**
 * Utilities for polyline encoding and decoding.<br>
 * <br>
 * See <a href=
 * "https://developers.google.com/maps/documentation/javascript/reference#encoding"
 * >Encoding Utils API Doc</a>
 */
public class Encoding {

    private Encoding() {

    }

    public static List<LatLng> decodePath(String encodedPath) {
        List<LatLng> toReturn = new ArrayList<LatLng>();
        JavaScriptObject peers = _decodePath(encodedPath);
        int size = JsoHelper.arrayLength(peers);
        for (int i = 0; i < size; i++) {
            toReturn.add(LatLng.instance(JsoHelper.getValueFromJavaScriptObjectArray(peers, i)));
        }
        return toReturn;
    }

    private static native JavaScriptObject _decodePath(String encodedPath)/*-{
		return $wnd.google.maps.geometry.encoding.decodePath(encodedPath);
    }-*/;

    public static String encodePath(LatLng... latLngs) {
        return encodePath(Arrays.asList(latLngs));
    }

    public static String encodePath(List<LatLng> paths) {
        JsArray<JavaScriptObject> peers = JsArray.createArray().cast();
        for (LatLng latlng : paths) {
            peers.push(latlng.getJsObj());
        }
        return _encodePath(peers);
    }

    private static native String _encodePath(JavaScriptObject paths)/*-{
		return $wnd.google.maps.geometry.encoding.encodePath(paths);
    }-*/;

}
